class Editor.PanelEditor extends Backbone.View
  tagName: 'div'
  className: 'panel-editor'
  
  initialize: (options) ->
    @panel = options.root_item
    @item = @panel
    @dialog = new Editor.PanelEditor.Dialog({
      parent: this
    })
    @body = new Pettanr.Views.Panel.Body.Edit({
      panel: @root_item(),
      spot: null
    })
    @dock = new Editor.PanelEditor.Dock({parent: this})
    @credits = new Pettanr.Views.Panel.ShowModule.Credits({pictures: {}})
    
    @body.on('panel:resize', @panel_resize)
    @listenTo(@dock, 'http_post', @http_post)
    @listenTo(@dock, 'add:element', @add_element)
    @listenTo(@dock, 'add:credit', @add_credit)
  
  add_element: (element) ->
    @body.add_element(element)
  
  add_credit: (element) ->
    @credits.add_picture(element.picture())
  
  remove_element: (element) ->
    @body.remove_element(element)
  
  render: () ->
    this.$el.html('')
    this.$el.append(@dialog.render().el)
    @dialog.$el.dialog({
      autoOpen: false,
      width: 750, 
      height: 560
    })
    this.$el.append(@body.render().el)
    this.$el.append(@dock.render().el)
    this.$el.append(@credits.render().el)
    rb = new Tag.RowBreak()
    this.$el.append(rb.render().el)
    @dock.init_tabs()
    @dock.$el.tabs()
    this
  
  panel_resize: () ->
    my = @body.$el
    w = parseInt(my.width())
    h = parseInt(my.height())
    #$(trace + 'width').val(w)
    #$(trace + 'height').val(h)
  
  quit: () ->
    @dialog.$el.dialog('destroy')
  
  http_post: (url, dock) ->
    @trigger('http_post', url, this)  # send editor
  
  save: () ->
    @listenTo(@panel, 'save:success', @post_success)
    @listenTo(@panel, 'save:fail', @post_fail)
    @panel.save(@dock.save_data())
    false
  
  post_success: (model, response) ->
    Pettanr.History.lock_url = null  # release editor
    @trigger('success', model, response)
  
  post_fail: (model, response) ->
    @trigger('fail', response)
  
  root_item: () ->
    @panel
  
  dom_id: () ->
    'editor-' + Pettanr.to_s(@root_item().get('id'))
  
  dom_class: () ->
    'editor'

