class PanelsController < ApplicationController
  if Manifest.manifest.magic_numbers['run_mode'] == 0
    before_filter :authenticate_user, :only => [:new, :edit, :create, :update, :destroy, :catch]
    before_filter :authenticate_author, :only => [:new, :edit, :create, :update, :destroy, :catch]
  else
    before_filter :authenticate_reader, :only => [
      :index, :show, :by_scroll, :by_sheet, :by_author, :by_speech_balloon_template
    ]
    before_filter :authenticate_user, :only => [:new, :edit, :create, :update, :destroy, :catch]
    before_filter :authenticate_author, :only => [:new, :edit, :create, :update, :destroy, :catch]
  end
  
  private
  def panel_list
    set_list
    @items = @list.items 
    @pager = @list.page_status.pager
    respond_to do |format|
      format.html 
      list_json_format @list, format
      format.atom 
      format.rss
    end
  end
  public
  def index
    if params[:mode] == 'filer'
      filer_list
    else
      panel_list
    end
  end
  
  def by_scroll
    filer_list
  end
  
  def by_sheet
    filer_list
  end
  
  def by_author
    filer_list
  end
  
  def by_speech_balloon_template
    filer_list
  end
  
  def show_html_format format
    format.html {
      if @operators.author
        @new_scroll_items = assist_items('home', 'scrolls')
        @fresh_scroll_items = assist_items('home', 'scroll_panels').map {|sp| sp.scroll}
      end
    }
  end
  
  def show
    set_show
    respond_to do |format|
      show_html_format format
      show_prof_format format
      if params[:with_elements]
        show_json_format_for_root format
      else
        show_json_format format
      end
    end
  end
  
  def new
    set_new
    respond_to do |format|
      format.html {
        @editor = Editor::PanelEditor.new @item, @operators
        render :template => @editor.template_name, :locals => {
          :editor => @editor
        }
      }
      format.json { render json: @item.to_json }
    end
  end
  
  def edit
    set_edit
    respond_to do |format|
      format.html {
        @editor = Editor::PanelEditor.new @item, @operators
        render :template => @editor.template_name, :locals => {
          :editor => @editor
        }
      }
      format.json { render json: @item.to_json }
    end
  end
  
  def create
    set_model
    @item = @my_model_class.new
#    @item.boosts 'post'
    jsn = nil
    if params[:json]
      jsn = JSON.parse_no_except(params[:json])
    end
    @prm = if params[:panel] == nil or params[:panel].empty?
       jsn
    else
       params[:panel]
    end
    @item.class.fold_extend_settings @prm
    #@item.refresh
    respond_to do |format|
      if @item.store @prm, @operators
        created_html_format format
        created_json_format format
      else
        format.html {
          flash[:notice] = I18n.t('flash.notice.not_created', :model => @my_model_class.model_name.human)
          @editor = Editor::PanelEditor.new @item, @operators
          render :template => @editor.template_name, :locals => {
            :editor => @editor
          }
        }
        not_created_json_format format
      end
    end
  end
  
  def update
    @item = Panel.edit(params[:id], @operators)
    @item.boosts 'post'
    jsn = nil
    if params[:json]
      jsn = JSON.parse(params[:json])
    end
    @prm = params[:panel] || jsn
    @item.class.fold_extend_settings @prm
    @item.attributes = @prm
    # @item.refresh
    respond_to do |format|
      if @item.store @prm, @operators
        updated_html_format format
        updated_json_format format
      else
        format.html {
          flash[:notice] = I18n.t('flash.notice.not_updated', :model => @my_model_class.model_name.human)
          @editor = Editor::PanelEditor.new @item, @operators
          render :template => @editor.template_name, :locals => {
            :editor => @editor
          }
        }
        not_updated_json_format format
      end
    end
  end
  
  def destroy
    @item = Panel.edit(params[:id], @operators)
    respond_to do |format|
      Panel.transaction do
        if @item.destroy_with_elements
          flash[:notice] = I18n.t('flash.notice.destroyed', :model => Panel.model_name.human)
          format.html { redirect_to '/home/panels' }
          format.json { head :ok }
        else
          flash[:notice] = I18n.t('flash.notice.not_destroyed', :model => Panel.model_name.human)
          format.html { redirect_to @item }
          format.json { render json: @item.errors, status: :unprocessable_entity }
        end
      end
    end
  end
  
  def catch
    @item = Panel.edit(params[:id], @operators)

    respond_to do |format|
      @operators.author.working_panel_id = @item.id
      if @operators.author.save
        format.html { redirect_to @item }
      else
      end
    end
  end

end
