class Sheet < Peta::Root
  load_manifest
  has_many :sheet_panels
  has_many :story_sheets
  belongs_to :author
  
  validates :caption, :presence => true, :length => {:maximum => 100}
  validates :width, :presence => true, :numericality => true, :natural_number => true
  validates :height, :presence => true, :numericality => true, :natural_number => true
  validates :visible, :presence => true, :numericality => true, :inclusion => {:in => 0..1}
  accepts_nested_attributes_for :sheet_panels, :allow_destroy => true
  
  def supply_default
    self.visible = 0 if self.visible.blank?
    self.author_id = nil
  end
  
  def overwrite operators
    return false unless operators.author
    self.author_id = operators.author.id
  end
  
  def visible? operators
    case super
    when nil # super return
      return true
    when false
      return false
    else
      self.visible > 0
    end
  end
  
  def usable? operators
    self.visible? operators
  end
  
  def symbol_filename
  end
  
  def self.public_list_where list
    'sheets.visible > 0'
  end
  
  def self.show_opt
    {:include => {:sheet_panels => {:panel => {}}, :author => {}}}
  end
  
  def self.show_json_opt
    {:include => {:sheet_panels => {:include => {:panel => {}}}, :author => {}}}
  end
  
  def scenario
    panels.map {|panel|
      panel.scenario
    }.join
  end
  
  def plain_scenario
    panels.map {|panel|
      panel.plain_scenario
    }.join
  end
  
  def licensed_pictures
    r = {}
    self.scenario_elements.each do |elm|
      r.merge!(elm.licensed_pictures)
    end
    r
  end
  
  def copyable?
    r = true
    Sheet.each_element_class_names do |n|
      self.elements_by_class_name(n).each do |elm|
        next if elm.copyable?
        r = false
        break
      end
      break unless r
    end
    r
  end
  
  def copy
    attr = self.copy_attributes
    Sheet.each_element_class_names do |n|
      element_attr = Sheet.class_name_to_class(n).panelize(
        self.elements_by_class_name(n).map {|elm|
          elm.copy_attributes.merge elm.panel_attributes
        }
      )
      attr.merge! element_attr
    end
    attr
  end
  
end
