Pettanr::Application.routes.draw do

  devise_for :users, controllers: {sessions: 'user_sessions'}
  devise_for :admins
  devise_for :demand_users
  
  Manifest.manifest.system_resources.templates.each do |template_name, template|
    if template.add_route?
      template.template_items.each do |klass, name|
        mount Module.const_get(klass)::Engine => "/#{name}"
      end
    end
  end
  
  resources :folders do
    new do
      get :new
    end
    collection do
      get :root
      get :index
      get :watch
      get :show
      post :create
    end
    member do
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :scrolls do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_author
      get :by_panel
      get :play
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :scroll_panels do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_panel
      get :by_scroll
      get :by_author
      get :play
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :comics do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_author
      get :by_story
      get :play
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :comic_stories do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_comic
      get :by_story
      get :by_author
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :stories do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_comic
      get :by_sheet
      get :by_author
      get :play
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :story_sheets do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_story
      get :by_sheet
      get :by_author
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :sheets do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :story_sheets
      get :stories
      get :sheet_panels
      get :panels
      get :by_story
      get :by_panel
      get :by_author
      get :play
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :sheet_panels do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_sheet
      get :by_panel
      get :by_author
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :panels do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_scroll
      get :by_sheet
      get :by_author
      get :by_speech_balloon_template
      get :catch
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :panel_pictures do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_panel
      get :by_author
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :speech_balloons do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_panel
      get :by_author
      get :by_speech_balloon_template
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :balloons do
    collection do
      get :index
      get :show
    end
    member do
      get :by_author
      get :by_speech_balloon
      get :by_speech_balloon_template
      get :by_system_picture
      get :edit
      put :update
    end
  end
  resources :speeches do
    collection do
      get :index
      get :show
    end
    member do
      get :by_author
      get :by_speech_balloon
      get :by_author
      get :by_speech_balloon_template
      get :by_writing_format
      get :edit
      put :update
    end
  end
  resources :ground_pictures do
    new do
      get :new
    end
    collection do
      get :index
      get :show
    end
    member do
      get :by_panel
      get :by_author
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :ground_colors do
    new do
      get :new
    end
    collection do
      get :index
      get :show
    end
    member do
      get :by_panel
      get :by_author
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :original_pictures do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :edit
      put :update
      delete :destroy
      get :history
    end
  end
  resources :pictures do
    collection do
      get :index
      get :show
      get :credit
      get :search
    end
    member do
      get :by_artist
      get :credit
    end
  end
  resources :resource_pictures do
    collection do
      get :index
      get :show
      get :new
      post :create
    end
    member do
      get :by_original_picture
      get :by_license_group
      get :by_license
      get :by_artist
      delete :destroy
      get :credit
    end
  end
  resources :resource_picture_pictures do
    collection do
      get :index
      get :show
    end
    member do
      get :by_original_picture
      get :by_resource_picture
      get :by_picture
    end
  end
  resources :speech_balloon_templates do
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_panel
      get :by_system_picture
      put :update
      delete :destroy
    end
  end
  resources :writing_formats do
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :speeches
      get :by_system_picture
      get :speeches_count
      put :update
      delete :destroy
    end
  end
  resources :license_groups do
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :by_resource_picture
      put :update
      delete :destroy
    end
  end
  resources :licenses do
    collection do
      get :index
      get :show
      get :search
      post :create
    end
    member do
      get :resource_pictures
      get :by_license_group
      get :by_system_picture
      get :resource_pictures_count
      put :update
      delete :destroy
    end
  end
  resources :authors do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :artists do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
    end
    member do
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :system_pictures do
    collection do
      get :index
      get :show
    end
    member do
      #get :balloons
      get :speech_balloon_templates
      get :licenses
      delete :destroy
    end
  end
  resources :original_picture_license_groups do
    new do
      post :new
    end
    collection do
      post :create
    end
  end
  resources :original_picture_licenses do
    new do
      post :new
    end
    collection do
      post :create
    end
  end
  resources :provider_sources do
    collection do
      get :index
      post :import
      get :list
      get :browse
    end
    member do
    end
  end
  resources :providers do
    collection do
      get :index
      get :show
      get :list
      get :browse
    end
    member do
      delete :destroy
    end
  end
  resources :provider_statuses do
    collection do
      get :index
      get :show
      get :list
      get :browse
    end
    member do
      get :edit
      put :update
      delete :destroy
      post :licenses_import
      post :artists_import
      post :original_pictures_import
      post :import
    end
  end
  resources :demanders do
    new do
      get :new
    end
    collection do
      get :index
      get :show
      post :create
      get :list
      get :browse
      post :req
      get :licenses_export
      get :artists_export
      get :original_pictures_export
      get :pictures_export
      get :export
    end
    member do
      get :edit
      put :update
      delete :destroy
    end
  end
  resources :demander_statuses do
    collection do
      get :index
      get :show
      get :list
      get :browse
    end
    member do
      get :edit
      put :update
      delete :destroy
    end
  end
  # The priority is based upon order of creation:
  # first created -> highest priority.

  # Sample of regular route:
  #   match 'products/:id' => 'catalog#view'
  # Keep in mind you can assign values other than :controller and :action
  
  # resource_pictures/1.png?subdir=full
  # match 'resource_pictures/full/:id(.:format)/' => 'resource_pictures#show'
  # match 'pictures/:subdir/:id(.:format)/' => 'pictures#show'
  #match 'scroll_panels/scroll/:id(.:format)' => 'scroll_panels#scroll'
  match 'top/(:action)', :controller => 'top'
  match 'home/(:action)', :controller => 'home'
  match 'system/(:action)', :controller => 'system'
  #match 'authors/(:action(/:id))', :controller => 'authors'
  
  # Sample of named route:
  #   match 'products/:id/purchase' => 'catalog#purchase', :as => :purchase
  # This route can be invoked with purchase_url(:id => product.id)

  # Sample resource route (maps HTTP verbs to controller actions automatically):
  #   resources :products

  # Sample resource route with options:
  #   resources :products do
  #     member do
  #       get 'short'
  #       post 'toggle'
  #     end
  #
  #     collection do
  #       get 'sold'
  #     end
  #   end

  # Sample resource route with sub-resources:
  #   resources :products do
  #     resources :comments, :sales
  #     resource :seller
  #   end

  # Sample resource route with more complex sub-resources
  #   resources :products do
  #     resources :comments
  #     resources :sales do
  #       get 'recent', :on => :collection
  #     end
  #   end

  # Sample resource route within a namespace:
  #   namespace :admin do
  #     # Directs /admin/products/* to Admin::ProductsController
  #     # (app/controllers/admin/products_controller.rb)
  #     resources :products
  #   end

  # You can have the root of your site routed with "root"
  # just remember to delete public/index.html.
  root :to => 'top#index'

  # See how all your routes lay out with "rake routes"

  # This is a legacy wild controller route that's not recommended for RESTful applications.
  # Note: This route will make all actions in every controller accessible via GET requests.
  match ':controller(/:action(/:id(.:format)))'
end
